@@ -1,18 +1,38 @@
 cal.yr <-
-function (x, format="%Y-%m-%d") 
+function( x,
+     format = "%Y-%m-%d",
+         wh = NULL )
 {
 cl.typ <- c("Date","POSIXct","POSIXlt","date","dates","chron")
 # Check if the input is a data frame and convert
-  if( inherits( x, "data.frame" ) )
+  if( inherits( x, "data.frame" ) & is.null(wh) & missing(format) )
     {
     # Indicator of where a date-type variable is
     wh <- sapply( x, inherits, cl.typ )
     # The positions
     wh <- (1:length(wh))[wh]
-    # Convert them
-    for( i in wh ) x[,i] <- cal.yr( x[,i] )
+    }
+  if( inherits( x, "data.frame" ) & is.null(wh) & !missing(format)  )
+    {
+    # Indicator of where the character variables are
+    wh <- sapply( x, is.character )
+    # The positions
+    wh <- (1:length(wh))[wh]
+    }
+  if( inherits( x, "data.frame" ) & is.vector(wh) )
+    {
+    if( is.character(wh) ) wh <- match( wh, names(x) )
+    # Convert the dates or the character variables
+    for( i in wh )
+       {
+       if( is.character(x[,i]) )
+         x[,i] <- cal.yr( x[,i], format=format )
+       else
+         x[,i] <- cal.yr( x[,i] )
+       }
     return( x )
     }
+# Finally, down to business --- converting a vector to decimal years:
 # Check if the input is some kind of date or time object
   if( any( inherits( x, cl.typ ) ) )
            x <- as.Date( as.POSIXct( x ) )
